readSpec: readSpec

Description Usage Arguments Value Examples

View source: R/io.R

Description

Get a spec from a file, separating and reading the yaml header, and sourcing the r code with dget.

Usage

1

Arguments

file

The file to read

Value

A list with names header and fun

Examples

1
readSpec("mtcars.R") 

Peder2911/Codder documentation built on Oct. 30, 2019, 9:40 p.m.