Description Usage Arguments Value Examples
Get a spec from a file, separating and reading the yaml header, and sourcing the r code with dget.
1 |
file |
The file to read |
A list with names header and fun
1 | readSpec("mtcars.R")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.